import { defineStore } from 'pinia'
import { ref } from 'vue'
import type { UserInfo } from '@/api/user'
import { userApi } from '@/api/user'



export const useUserStore = defineStore('user', () => {
  let userInfo = ref<UserInfo | null>(null)
  const token = ref<string | null>(null)

  // 获取用户信息
  const getUserInfo = async () => {
    try {
      const data = await userApi.getCurrentUser()
      userInfo = data
      return data
    } catch (error) {
      console.error('获取用户信息失败:', error)
      return null
    }
  }

  // 设置token
  const setToken = (token: string) => {
    localStorage.setItem('token', token)
  }

  // 清除用户信息
  const clearUserInfo = () => {
    userInfo.value = null
    token.value = null
    localStorage.removeItem('token')
  }

  return {
    userInfo,
    token,
    getUserInfo,
    setToken,
    clearUserInfo
  }
})
